@@ -8,6 +8,17 @@
 # ------------------------------------------------------------------------
 import sys
 
+import glob
+import os
+if os.path.exists( 'fitz/__init__.py'):
+    if not glob.glob( 'fitz/_fitz*'):
+        print( '#' * 40)
+        print( '# Warning: current directory appears to contain an incomplete')
+        print( '# fitz/ installation directory so "import fitz" may fail.')
+        print( '# This can happen if current directory is a PyMuPDF source tree.')
+        print( '# Suggest changing to a different current directory.')
+        print( '#' * 40)
+
 from fitz.fitz import *
 
 # define the supported colorspaces for convenience
@@ -43,14 +54,34 @@ def cleanup_tools(TOOLS):
 
 atexit.register(cleanup_tools, TOOLS)
 
-if fitz.VersionFitz != fitz.TOOLS.mupdf_version():
-    v1 = fitz.VersionFitz.split(".")
-    v2 = fitz.TOOLS.mupdf_version().split(".")
-    if v1[:-1] != v2[:-1]:
-        raise ValueError(
-            "MuPDF library mismatch %s <> %s"
-            % (fitz.VersionFitz, fitz.TOOLS.mupdf_version())
-        )
+
+# Require that MuPDF matches fitz.TOOLS.mupdf_version(); also allow use with
+# next minor version (e.g. 1.21.2 => 1.22), so we can test with mupdf master.
+#
+def v_str_to_tuple(s):
+    return tuple(map(int, s.split('.')))
+
+def v_tuple_to_string(t):
+    return '.'.join(map(str, t))
+
+mupdf_version_tuple = v_str_to_tuple(fitz.TOOLS.mupdf_version())
+mupdf_version_tuple_required = v_str_to_tuple(fitz.VersionFitz)
+mupdf_version_tuple_required_prev = (mupdf_version_tuple_required[0], mupdf_version_tuple_required[1]-1)
+mupdf_version_tuple_required_next = (mupdf_version_tuple_required[0], mupdf_version_tuple_required[1]+1)
+
+if mupdf_version_tuple[:2] not in (
+        mupdf_version_tuple_required_prev[:2],
+        mupdf_version_tuple_required[:2], 
+        mupdf_version_tuple_required_next[:2],
+        ):
+    raise ValueError(
+            f'MuPDF library {v_tuple_to_string(mupdf_version_tuple)!r} mismatch:'
+            f' require'
+            f' {v_tuple_to_string(mupdf_version_tuple_required_prev)!r}'
+            f' or {v_tuple_to_string(mupdf_version_tuple_required)!r}'
+            f' or {v_tuple_to_string(mupdf_version_tuple_required_next)!r}'
+            f'.'
+            )
 
 # copy functions in 'utils' to their respective fitz classes
 import fitz.utils
